#
# spec file for package libdatrie
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libdatrie
Version:        0.2.9
Release:        lp152.3.2
Summary:        Double-Array Trie Library
License:        LGPL-2.1
Group:          System/Libraries
Url:            http://linux.thai.net/~thep/datrie/datrie.html
Source:         http://linux.thai.net/pub/thailinux/software/libthai/%{name}-%{version}.tar.xz
Source99:       baselibs.conf
# sent upstream (theppitak@gmail.com)
Patch0:         libdatrie-doxygen-version-check.patch
BuildRequires:  autoconf-archive
BuildRequires:  doxygen
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

%package -n libdatrie1
Summary:        Double-Array Trie Library
Group:          Development/Libraries/C and C++

%description -n libdatrie1
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

%package devel
Summary:        Double-Array Trie Library (development)
Group:          Development/Libraries/C and C++
Requires:       libdatrie1 = %{version}

%description devel
This is an implementation of double-array structure for representing
trie, as proposed by Junichi Aoe.

This package contains the development files for libdatrie.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fiv
%configure \
        --disable-static --with-pic \
        --with-html-docdir=%{_docdir}/libdatrie/html
make %{?_smp_mflags}

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/libdatrie.la
# This is not installed where it should
mv %{buildroot}%{_datadir}/doc/libdatrie/README.migration %{buildroot}%{_docdir}/libdatrie/

%post -n libdatrie1 -p /sbin/ldconfig

%postun -n libdatrie1 -p /sbin/ldconfig

%files -n libdatrie1
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_libdir}/libdatrie.so.1*

%files devel
%defattr(-,root,root)
%{_bindir}/trietool*
%doc %{_mandir}/man*/trietool*.1.gz
%{_includedir}/datrie/
%{_libdir}/libdatrie.so
%{_libdir}/pkgconfig/datrie-0.2.pc
%doc %{_docdir}/libdatrie/

%changelog
* Tue Aug 18 2015 pgajdos@suse.com
- update to version 0.2.9
  * Fix infinite loop on empty trie iteration.
  * Document about alphabet size.
  * Disable timestamp in Doxygen-generated doc.
  * etc. see ChangeLog
- remove libdatrie-doxygen-found-is-enough.patch in favour of
  libdatrie-doxygen-version-check.patch
* Tue Aug 18 2015 dimstar@opensuse.org
- Add libdatrie-doxygen-found-is-enough.patch: when we find
  doxygen, we assume it is new enough. The configure script uses
  'expr 1.8.4 \< $DOXYGEN_VER', which returns false for 1.8.10.
- For safeguard, we specify the minimal required version of
  doxygen (1.8.4) in the buildrequirements.
* Wed Feb  4 2015 p.drouand@gmail.com
- Update to version 0.2.8
  * Fix compiler warnings in test suites.
  * Fix edge-case error on alphabet set of size 255.
  * Fail trie operations on non-alphabet inputs, rather than silently
    allowing them to sneak in as false keys.
  * Improved documentation.
- Add xz build require to keep SLE11 support
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Wed Feb 23 2011 vuntz@opensuse.org
- Add missing baselibs.conf.
* Sun Sep 19 2010 vuntz@opensuse.org
- Update to version 0.2.4:
  + Close file on saving trie.
  + Add trie_store_if_absent() API which fails on adding duplicated
    key. This is useful for preventing race condition in
    multi-thread applications.
  + Add trie_fread() and trie_fwrite() APIs for reading/writing
    trie data in an open file, allowing trie to be embeded as part
    of a bigger file.
- Changes from version 0.2.3:
  + More robustness against corrupted trie files.
  + License clarification in individual source files.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Jan  4 2010 vuntz@opensuse.org
- Update to version 0.2.2:
  + Support building with linkers without symbol versioning
    supports, including Mac, Cygwin, MinGW.
  + Support other iconv implementations than that's in glibc, for
    Mac and MinGW.
- Changes from version 0.2.1:
  + Fix errors in documentation
  + Symbol versioning to ease upgrade across SONAME
  + Minor cleanups
- Changes from version 0.2.0:
  + New APIs for performance: trie_state_copy(),
    trie_state_is_single()
  + Clean-ups
- Changes from version 0.1.99.2:
  + More robust handling of alphabet ranges
  + Allow co-existence with libdatrie0
- Changes from version 0.1.99.1:
  + Breaking ABI with libdatrie0
  + More capacity with 32-bit node index
  + Adjusted API for non-file trie usage
  + All data in one file, no more *.br and *.tl split
  + Drop SBTrie wrapper; all features are merged into Trie
  + Domain characters are now Unicode
* Thu Feb 19 2009 crrodriguez@suse.de
- remove static libraries
* Mon Apr  7 2008 uli@suse.de
- update -> 0.1.3 (fixes bug that keeps new libthai from
  building, bnc #326002)
* Tue Oct 30 2007 uli@suse.de
- initial package
